@@ -156,6 +156,22 @@ def diff_one(model1: pw.Model, model2: pw.Model, **kwargs) -> t.List[str]:
         else:
             changes.append(drop_index(model1, name))
 
+    # Check additional compound indexes
+    indexes1 = model1._meta.indexes
+    indexes2 = model2._meta.indexes
+
+    # Drop compound indexes
+    indexes_to_drop = set(indexes2) - set(indexes1)
+    for index in indexes_to_drop:
+        if isinstance(index[0], (list, tuple)) and len(index[0]) > 1:
+            changes.append(drop_index(model1, name=index[0]))
+
+    # Add compound indexes
+    indexes_to_add = set(indexes1) - set(indexes2)
+    for index in indexes_to_add:
+        if isinstance(index[0], (list, tuple)) and len(index[0]) > 1:
+            changes.append(add_index(model1, name=index[0], unique=index[1]))
+
     return changes
 
 
@@ -168,8 +184,8 @@ def diff_many(models1, models2, migrator=None, reverse=False):
         models1 = reversed(models1)
         models2 = reversed(models2)
 
-    models1 = OrderedDict([(m._meta.name, m) for m in models1])
-    models2 = OrderedDict([(m._meta.name, m) for m in models2])
+    models1 = OrderedDict([(m._meta.table_name, m) for m in models1])
+    models2 = OrderedDict([(m._meta.table_name, m) for m in models2])
 
     changes = []
 
@@ -310,18 +326,15 @@ def change_not_null(Model: pw.Model, name: str, null: bool) -> str:
     return "migrator.%s('%s', %s)" % (operation, Model._meta.table_name, repr(name))
 
 
-def add_index(Model: pw.Model, name: str, unique: bool) -> str:
+def add_index(
+    Model: pw.Model, name: t.Union[str, t.Iterable[str]], unique: bool
+) -> str:
     """Generate migrations."""
-    operation = "add_index"
-    return "migrator.%s('%s', %s, unique=%s)" % (
-        operation,
-        Model._meta.table_name,
-        repr(name),
-        unique,
+    return (
+        f"migrator.add_index('{Model._meta.table_name}', {repr(name)}, unique={unique})"
     )
 
 
-def drop_index(Model: pw.Model, name: str) -> str:
+def drop_index(Model: pw.Model, name: t.Union[str, t.Iterable[str]]) -> str:
     """Generate migrations."""
-    operation = "drop_index"
-    return "migrator.%s('%s', %s)" % (operation, Model._meta.table_name, repr(name))
+    return f"migrator.drop_index('{Model._meta.table_name}', {repr(name)})"
